@@ -4,8 +4,8 @@ import json
 
 class UserInfo(CMPClient):
 
-    def __init__(self, cmp_url, tenant_id):
-        super(UserInfo, self).__init__(cmp_url, tenant_id)
+    def __init__(self, cmp_url, tenant_id, cmp_secret_key, cmp_user_id):
+        super(UserInfo, self).__init__(cmp_url, tenant_id, cmp_secret_key, cmp_user_id)
 
     def query_user(self, user_id):
         """
