@@ -5,13 +5,15 @@ from .cdn_client import CdnClient
 from .cfs_client import CfsClient
 from .vpc_client import VpcClient
 from .dns_client import DnsClient
+from .postgres_client import PostgresClient
 
 prod_mapper = {
     'clb': ClbClient,
     'cdn': CdnClient,
     'cfs': CfsClient,
     'vpc': VpcClient,
-    'dns': DnsClient
+    'dns': DnsClient,
+    'postgres': PostgresClient
 }
 
 
@@ -43,4 +45,8 @@ def vpc_client():
 
 @proxy
 def dns_client():
-    return get_current_client('dns')
\ No newline at end of file
+    return get_current_client('dns')
+
+@proxy
+def postgres_client():
+    return get_current_client('postgres')
\ No newline at end of file
